@@ -33,7 +33,7 @@ DEFAULT_CLUSTER_RETRY_EXCEPTIONS = {
 
 LOGGER = logging.getLogger(__name__)
 TIMEOUT = 240
-MAX_SUPPORTED_API_VERSION = "v1"
+MAX_SUPPORTED_API_VERSION = "v2"
 
 
 def _collect_instance_data(directory, resource_object):
@@ -128,6 +128,8 @@ def _get_api_version(dyn_client, api_group, kind):
         log = f"Couldn't find {kind} in {api_group} api group"
         LOGGER.warning(log)
         raise NotImplementedError(log)
+
+    LOGGER.info(f"Using api version: {res.group_version}")
     return res.group_version
 
 
@@ -419,13 +421,12 @@ class Resource:
     def clean_up(self):
         if os.environ.get("CNV_TEST_COLLECT_LOGS", "0") == "1":
             try:
-                LOGGER.info(f"Collecting data for {self.kind} {self.name}")
                 _collect_data(resource_object=self)
             except Exception as exception_:
-                LOGGER.warning(
-                    f"Log collector failed to collect info for {self.kind} {self.name}\nexception: {exception_}"
-                )
+                LOGGER.warning(exception_)
 
+        data = self.to_dict()
+        LOGGER.info(f"Deleting {data}")
         self.delete(wait=True, timeout=self.timeout)
 
     @classmethod
@@ -619,16 +620,12 @@ class Resource:
         return res
 
     def delete(self, wait=False, timeout=TIMEOUT, body=None):
-        LOGGER.info(f"Delete {self.kind} {self.name}")
-        if self.exists:
-            data = self.instance.to_dict()
-            LOGGER.info(f"Deleting {data}")
-
         try:
             res = self.api.delete(name=self.name, namespace=self.namespace, body=body)
         except NotFoundError:
             return False
 
+        LOGGER.info(f"Delete {self.kind} {self.name}")
         if wait and res:
             return self.wait_deleted(timeout=timeout)
         return res
